==> wiki3_4_3.zip: wiki3_4_3/plugin/admin/AdminConfigHandler.pm <==
###############################################################################
#
# FSWikiưԤϥɥ
#
###############################################################################
package plugin::admin::AdminConfigHandler;
#use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self  = shift;
	my $wiki  = shift;
	my $cgi   = $wiki->get_CGI;
	
	$wiki->set_title("Ķ");
	
	if($cgi->param("SAVE") ne ""){
		return $self->save_config($wiki);
	} else {
		return $self->config_form($wiki);
	}
}

#==============================================================================
# ե
#==============================================================================
sub config_form {
	my $self = shift;
	my $wiki = shift;
	
	my $config  = &Util::load_config_hash($wiki,$wiki->config('config_file'));
	
	# ƥץ졼Ȥ˥ѥ᡼򥻥å
	my $tmpl = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/admin_config.tmpl",
	                               die_on_bad_params => 0);
	$tmpl->param(
		SITE_TITLE          => $config->{site_title},
		ADMIN_NAME          => $config->{admin_name},
		ADMIN_MAIL          => $config->{admin_mail},
		ADMIN_MAIL_PUB      => $config->{admin_mail_pub},
		PAGELIST            => $config->{pagelist},
		BR_MODE             => $config->{br_mode},
#		USE_SIDEBAR         => $config->{use_sidebar},
		ACCEPT_EDIT         => $config->{accept_edit},
		AUTO_KEYWORD_PAGE   => $config->{auto_keyword_page},
		KEYWORD_SLASH_PAGE  => $config->{keyword_slash_page},
		WIKINAME            => $config->{wikiname},
		ACCEPT_ATTACH_DELETE=> $config->{accept_attach_delete},
		SESSION_LIMIT       => $config->{session_limit}
	);
	
	return "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	       $tmpl->output().
	       "<input type=\"hidden\" name=\"action\" value=\"ADMINCONFIG\">\n";
	       "</form>\n";
}

#==============================================================================
# ¸
#==============================================================================
sub save_config {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	my $config = &Util::load_config_hash($wiki,$wiki->config('config_file'));
	
	$config->{site_title}     = $cgi->param("site_title");
	$config->{admin_name}     = $cgi->param("admin_name");
	$config->{admin_mail}     = $cgi->param("admin_mail");
	$config->{admin_mail_pub} = $cgi->param("admin_mail_pub");

	$config->{pagelist}    = $cgi->param("pagelist");
	$config->{br_mode}     = $cgi->param("br_mode");
#	$config->{use_sidebar} = $cgi->param("use_sidebar");
	$config->{accept_edit} = $cgi->param("accept_edit");
	$config->{wikiname}    = $cgi->param("wikiname");
	$config->{auto_keyword_page}    = $cgi->param("auto_keyword_page");
	$config->{keyword_slash_page}   = $cgi->param("keyword_slash_page");
	$config->{accept_attach_delete} = $cgi->param("accept_attach_delete");
	
	$config->{session_limit} = $cgi->param("session_limit");
	&Util::save_config_hash($wiki,$wiki->config('config_file'),$config);
	
	return "¸ޤ\n";

}

1;

==> wiki3_5_1.zip: wiki3_5_1/plugin/admin/AdminConfigHandler.pm <==
###############################################################################
#
# FSWikiưԤϥɥ
#
###############################################################################
package plugin::admin::AdminConfigHandler;
#use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self  = shift;
	my $wiki  = shift;
	my $cgi   = $wiki->get_CGI;
	
	$wiki->set_title("Ķ");
	
	if($cgi->param("SAVE") ne ""){
		return $self->save_config($wiki);
	} else {
		return $self->config_form($wiki);
	}
}

#==============================================================================
# ե
#==============================================================================
sub config_form {
	my $self = shift;
	my $wiki = shift;
	
	my $config  = &Util::load_config_hash($wiki,$wiki->config('config_file'));
	
	# ƥץ졼Ȥ˥ѥ᡼򥻥å
	my $tmpl = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/admin_config.tmpl",
	                               die_on_bad_params => 0);
	$tmpl->param(
		SITE_TITLE          => $config->{site_title},
		ADMIN_NAME          => $config->{admin_name},
		ADMIN_MAIL          => $config->{admin_mail},
		ADMIN_MAIL_PUB      => $config->{admin_mail_pub},
		PAGELIST            => $config->{pagelist},
		BR_MODE             => $config->{br_mode},
		ACCEPT_EDIT         => $config->{accept_edit},
		AUTO_KEYWORD_PAGE   => $config->{auto_keyword_page},
		KEYWORD_SLASH_PAGE  => $config->{keyword_slash_page},
		WIKINAME            => $config->{wikiname},
		ACCEPT_ATTACH_DELETE=> $config->{accept_attach_delete},
		SESSION_LIMIT       => $config->{session_limit},
		RSS_VERSION         => $config->{rss_version}
	);
	
	return "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	       $tmpl->output().
	       "<input type=\"hidden\" name=\"action\" value=\"ADMINCONFIG\">\n";
	       "</form>\n";
}

#==============================================================================
# ¸
#==============================================================================
sub save_config {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	my $config = &Util::load_config_hash($wiki,$wiki->config('config_file'));
	
	$config->{site_title}     = $cgi->param("site_title");
	$config->{admin_name}     = $cgi->param("admin_name");
	$config->{admin_mail}     = $cgi->param("admin_mail");
	$config->{admin_mail_pub} = $cgi->param("admin_mail_pub");

	$config->{pagelist}    = $cgi->param("pagelist");
	$config->{br_mode}     = $cgi->param("br_mode");
	$config->{accept_edit} = $cgi->param("accept_edit");
	$config->{wikiname}    = $cgi->param("wikiname");
	$config->{auto_keyword_page}    = $cgi->param("auto_keyword_page");
	$config->{keyword_slash_page}   = $cgi->param("keyword_slash_page");
	$config->{accept_attach_delete} = $cgi->param("accept_attach_delete");
	
	$config->{session_limit} = $cgi->param("session_limit");
	$config->{rss_version}   = $cgi->param("rss_version");
	
	&Util::save_config_hash($wiki,$wiki->config('config_file'),$config);
	
	return "¸ޤ\n";

}

1;
